@@ -5,7 +5,7 @@
 
 package JTM::Boilerplate;
 # ABSTRACT: Default Boilerplate for Joelle Maslak's Code
-$JTM::Boilerplate::VERSION = '2.231930';
+$JTM::Boilerplate::VERSION = '2.231980';
 use strict;
 use warnings;
 
@@ -33,7 +33,8 @@ sub import ( $self, $type = 'script' ) {
     warnings->import::into($target);
     autodie->import::into($target);
 
-    feature->import::into( $target, ':5.22' );
+    my ($ver) = "$PERL_VERSION" =~ m/^v(\d+\.\d+)\..*$/;
+    feature->import::into( $target, ":$ver" );
 
     utf8->import::into($target);    # Allow UTF-8 Source
 
@@ -47,6 +48,8 @@ sub import ( $self, $type = 'script' ) {
         Moose::Util::TypeConstraints->import::into($target);
         MooseX::StrictConstructor->import::into($target);
         namespace::autoclean->import::into($target);
+    } else {
+        Feature::Compat::Class->import::into($target);
     }
 
     Carp->import::into($target);
@@ -55,6 +58,9 @@ sub import ( $self, $type = 'script' ) {
 
     feature->import::into( $target, 'postderef' );    # Not needed if feature bundle >= 5.23.1
 
+    Feature::Compat::Defer->import::into($target);
+    Feature::Compat::Try->import::into($target);
+
     # We haven't been using this
     # feature->import::into($target, 'refaliasing');
     feature->import::into( $target, 'signatures' );
@@ -69,7 +75,7 @@ sub import ( $self, $type = 'script' ) {
 
     # For "re 'strict'" feature
     warnings->unimport::out_of( $target, 'experimental::re_strict' );
-    re->import( 'strict' );
+    re->import('strict');
 
     if ( $PERL_VERSION ge v5.32.0 ) {
         # Turn off indirect syntax
@@ -86,10 +92,6 @@ sub import ( $self, $type = 'script' ) {
 
         # Turn off bareword filehandles
         feature->unimport::out_of( $target, 'bareword_filehandles' );
-
-        # Turn on Try/Catch
-        feature->import::into( $target, 'try' );
-        warnings->unimport::out_of( $target, 'experimental::try' );
     }
 
     return;
@@ -109,7 +111,7 @@ JTM::Boilerplate - Default Boilerplate for Joelle Maslak's Code
 
 =head1 VERSION
 
-version 2.231930
+version 2.231980
 
 =head1 SYNOPSIS
 
